@@ -18,23 +18,26 @@ from moai_adk.cli.worktree.registry import WorktreeRegistry
 
 
 class WorktreeManager:
-    """Manages Git worktrees for parallel SPEC development.
+    """Manages Git worktrees for parallel SPEC development with project namespace support.
 
     This class provides high-level operations for creating, removing,
     switching, and maintaining Git worktrees. It integrates with
     GitPython for Git operations and WorktreeRegistry for metadata
-    persistence.
+    persistence. Worktrees are organized by project name namespace to
+    support multiple projects: /worktrees/{project-name}/{SPEC-ID}
     """
 
-    def __init__(self, repo_path: Path, worktree_root: Path) -> None:
+    def __init__(self, repo_path: Path, worktree_root: Path, project_name: str | None = None) -> None:
         """Initialize the worktree manager.
 
         Args:
             repo_path: Path to the main Git repository.
             worktree_root: Root directory for all worktrees.
+            project_name: Project name for namespace organization. Defaults to repo directory name.
         """
         self.repo = Repo(repo_path)
         self.worktree_root = Path(worktree_root)
+        self.project_name = project_name or repo_path.name
         self.registry = WorktreeRegistry(self.worktree_root)
 
     def create(
@@ -62,7 +65,7 @@ class WorktreeManager:
             GitOperationError: If Git operation fails.
         """
         # Check if worktree already exists
-        existing = self.registry.get(spec_id)
+        existing = self.registry.get(spec_id, project_name=self.project_name)
         if existing and not force:
             raise WorktreeExistsError(spec_id, existing.path)
 
@@ -77,12 +80,12 @@ class WorktreeManager:
         if branch_name is None:
             branch_name = f"feature/{spec_id}"
 
-        # Create worktree path
-        worktree_path = self.worktree_root / spec_id
+        # Create worktree path with project_name namespace
+        worktree_path = self.worktree_root / self.project_name / spec_id
 
         try:
-            # Create parent directory if needed
-            self.worktree_root.mkdir(parents=True, exist_ok=True)
+            # Create parent directory if needed (including project_name namespace)
+            worktree_path.parent.mkdir(parents=True, exist_ok=True)
 
             # Fetch latest
             try:
@@ -128,7 +131,7 @@ class WorktreeManager:
             )
 
             # Register in registry
-            self.registry.register(info)
+            self.registry.register(info, project_name=self.project_name)
 
             return info
 
@@ -151,7 +154,7 @@ class WorktreeManager:
             UncommittedChangesError: If worktree has uncommitted changes (unless force=True).
             GitOperationError: If Git operation fails.
         """
-        info = self.registry.get(spec_id)
+        info = self.registry.get(spec_id, project_name=self.project_name)
         if not info:
             raise WorktreeNotFoundError(spec_id)
 
@@ -177,7 +180,7 @@ class WorktreeManager:
                     shutil.rmtree(info.path)
 
             # Unregister from registry
-            self.registry.unregister(spec_id)
+            self.registry.unregister(spec_id, project_name=self.project_name)
 
         except (WorktreeNotFoundError, UncommittedChangesError):
             raise
@@ -192,7 +195,7 @@ class WorktreeManager:
         Returns:
             List of WorktreeInfo instances.
         """
-        return self.registry.list_all()
+        return self.registry.list_all(project_name=self.project_name)
 
     def sync(
         self,
@@ -218,7 +221,7 @@ class WorktreeManager:
             MergeConflictError: If merge conflict occurs and auto_resolve is False.
             GitOperationError: If Git operation fails.
         """
-        info = self.registry.get(spec_id)
+        info = self.registry.get(spec_id, project_name=self.project_name)
         if not info:
             raise WorktreeNotFoundError(spec_id)
 
@@ -376,7 +379,7 @@ class WorktreeManager:
 
             # Update last accessed time
             info.last_accessed = datetime.now().isoformat() + "Z"
-            self.registry.register(info)
+            self.registry.register(info, project_name=self.project_name)
 
         except (WorktreeNotFoundError, MergeConflictError):
             raise
