@@ -10,6 +10,8 @@ import os
 from datetime import datetime, timezone
 from typing import Any, Dict, List, Optional
 
+import yaml
+
 # Conditional import of ContextManager
 try:
     from moai_adk.core.context_manager import (
@@ -25,7 +27,7 @@ except ImportError:
 
 def extract_project_metadata(project_root: str) -> Dict[str, Any]:
     """
-    Extract project metadata from config.json.
+    Extract project metadata from config.yaml.
 
     Args:
         project_root: Root directory of the project
@@ -34,22 +36,22 @@ def extract_project_metadata(project_root: str) -> Dict[str, Any]:
         Dictionary containing project metadata
 
     Raises:
-        FileNotFoundError: If config.json doesn't exist
-        json.JSONDecodeError: If config.json is invalid
+        FileNotFoundError: If config.yaml doesn't exist
+        yaml.YAMLError: If config.yaml is invalid
     """
-    config_path = os.path.join(project_root, ".moai", "config", "config.json")
+    config_path = os.path.join(project_root, ".moai", "config", "config.yaml")
 
     if not os.path.exists(config_path):
         raise FileNotFoundError(f"Config file not found: {config_path}")
 
     with open(config_path, "r", encoding="utf-8") as f:
-        config = json.load(f)
+        config = yaml.safe_load(f) or {}
 
     # Extract key metadata
     metadata = {
         "project_name": config.get("project", {}).get("name", "Unknown"),
         "mode": config.get("project", {}).get("mode", "personal"),
-        "owner": config.get("project", {}).get("owner", "@user"),
+        "github_profile": config.get("github", {}).get("profile_name", ""),
         "language": config.get("language", {}).get("conversation_language", "en"),
         "tech_stack": [],  # To be detected separately
     }
@@ -238,9 +240,7 @@ def save_command_context(
     try:
         context_mgr = ContextManager(project_root)
         absolute_paths = validate_phase_files(files_created, project_root)
-        phase_data = _prepare_phase_data(
-            phase_name, status, outputs, absolute_paths, next_phase
-        )
+        phase_data = _prepare_phase_data(phase_name, status, outputs, absolute_paths, next_phase)
         return _validate_and_save(context_mgr, phase_data)
 
     except Exception as e:
