@@ -3,11 +3,17 @@
 from moai_adk.core.config.migration import (
     get_conversation_language,
     get_conversation_language_name,
+    get_report_generation_config,
+    get_spec_git_workflow,
+    migrate_config_schema_v0_17_0,
     migrate_config_to_nested_structure,
 )
 
 __all__ = [
     "migrate_config_to_nested_structure",
+    "migrate_config_schema_v0_17_0",
     "get_conversation_language",
     "get_conversation_language_name",
+    "get_report_generation_config",
+    "get_spec_git_workflow",
 ]
