@@ -43,7 +43,6 @@ class OutputStyleDetector:
         "yoda": "🧙 Yoda Master",
         "yoda-master": "🧙 Yoda Master",
         "tutorial": "🧙 Yoda Master",
-
         # Display values with emojis
         "🤖 R2-D2": "R2-D2",
         "R2-D2": "R2-D2",
@@ -150,10 +149,7 @@ class OutputStyleDetector:
                 yoda_files = list(moai_dir.rglob("*yoda*"))
                 if yoda_files:
                     # Check if any Yoda files are recently modified
-                    recent_yoda = any(
-                        f.stat().st_mtime > (time.time() - 300)  # Last 5 minutes
-                        for f in yoda_files
-                    )
+                    recent_yoda = any(f.stat().st_mtime > (time.time() - 300) for f in yoda_files)  # Last 5 minutes
                     if recent_yoda:
                         return "🧙 Yoda Master"
 
@@ -248,11 +244,7 @@ class OutputStyleDetector:
                 return None
 
             # Look for style indicators in recent responses
-            full_text = " ".join(
-                msg.get("content", "")
-                for msg in messages[-3:]
-                if msg.get("role") == "assistant"
-            )
+            full_text = " ".join(msg.get("content", "") for msg in messages[-3:] if msg.get("role") == "assistant")
 
             if not full_text:
                 return None
@@ -261,7 +253,13 @@ class OutputStyleDetector:
             text_lower = full_text.lower()
 
             # Yoda Master indicators
-            yoda_indicators = ["young padawan", "the force", "master", "wisdom", "patience"]
+            yoda_indicators = [
+                "young padawan",
+                "the force",
+                "master",
+                "wisdom",
+                "patience",
+            ]
             yoda_count = sum(1 for indicator in yoda_indicators if indicator in text_lower)
 
             if yoda_count >= 2:
@@ -269,8 +267,14 @@ class OutputStyleDetector:
 
             # Explanatory indicators
             if len(full_text) > 2000:  # Long responses
-                explanatory_count = sum(1 for phrase in
-                    ["let me explain", "here's how", "the reason is", "to understand"]
+                explanatory_count = sum(
+                    1
+                    for phrase in [
+                        "let me explain",
+                        "here's how",
+                        "the reason is",
+                        "to understand",
+                    ]
                     if phrase in text_lower
                 )
                 if explanatory_count >= 2:
@@ -308,7 +312,10 @@ class OutputStyleDetector:
 
         # Detection methods in priority order
         detection_methods = [
-            ("Session Context", lambda: self.detect_from_session_context(session_context or {})),
+            (
+                "Session Context",
+                lambda: self.detect_from_session_context(session_context or {}),
+            ),
             ("Environment", self.detect_from_environment),
             ("Behavioral Analysis", self.detect_from_behavioral_analysis),
             ("Settings File", self.detect_from_settings),
