@@ -4,7 +4,6 @@ Common utility functions
 """
 
 import asyncio
-import json
 import logging
 import re
 from dataclasses import dataclass, field
@@ -14,6 +13,7 @@ from typing import Dict, List, Optional
 from urllib.parse import urlparse
 
 import aiohttp
+import yaml
 
 logger = logging.getLogger(__name__)
 
@@ -49,9 +49,7 @@ class HTTPClient:
         self.session = aiohttp.ClientSession(
             connector=connector,
             timeout=timeout,
-            headers={
-                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36"
-            },
+            headers={"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36"},
         )
         return self
 
@@ -159,7 +157,7 @@ def create_report_path(base_path: Path, suffix: str = "report") -> Path:
 def format_duration(seconds: float) -> str:
     """Convert time (seconds) to readable format"""
     if seconds < 1:
-        return f"{seconds*1000:.0f}ms"
+        return f"{seconds * 1000:.0f}ms"
     elif seconds < 60:
         return f"{seconds:.1f}s"
     elif seconds < 3600:
@@ -172,9 +170,7 @@ def format_duration(seconds: float) -> str:
         return f"{hours}h {remaining_minutes}m"
 
 
-def calculate_score(
-    values: List[float], weights: Optional[List[float]] = None
-) -> float:
+def calculate_score(values: List[float], weights: Optional[List[float]] = None) -> float:
     """Calculate weighted average score"""
     if not values:
         return 0.0
@@ -223,11 +219,7 @@ class RateLimiter:
         now = datetime.now()
 
         # Remove old requests
-        self.requests = [
-            req_time
-            for req_time in self.requests
-            if (now - req_time).total_seconds() < self.time_window
-        ]
+        self.requests = [req_time for req_time in self.requests if (now - req_time).total_seconds() < self.time_window]
 
         return len(self.requests) < self.max_requests
 
@@ -236,17 +228,13 @@ class RateLimiter:
         if self.can_make_request():
             self.requests.append(datetime.now())
         else:
-            raise RateLimitError(
-                f"Rate limit exceeded: {self.max_requests} requests per {self.time_window}s"
-            )
+            raise RateLimitError(f"Rate limit exceeded: {self.max_requests} requests per {self.time_window}s")
 
     async def wait_if_needed(self):
         """Wait until request can be made"""
         if not self.can_make_request():
             oldest_request = min(self.requests)
-            wait_time = (
-                self.time_window - (datetime.now() - oldest_request).total_seconds()
-            )
+            wait_time = self.time_window - (datetime.now() - oldest_request).total_seconds()
             if wait_time > 0:
                 logger.info(f"Rate limiting: waiting {wait_time:.1f}s")
                 await asyncio.sleep(wait_time)
@@ -260,49 +248,47 @@ class RateLimitError(Exception):
 
 def load_hook_timeout() -> int:
     """
-    Load Hook timeout setting from .moai/config/config.json
+    Load Hook timeout setting from .moai/config/config.yaml
 
     Returns:
         int: timeout value (milliseconds), returns default 5000 if not configured
     """
     try:
-        config_path = Path(".moai/config/config.json")
+        config_path = Path(".moai/config/config.yaml")
         if not config_path.exists():
             return 5000  # Default value
 
         with open(config_path, "r", encoding="utf-8") as f:
-            config = json.load(f)
+            config = yaml.safe_load(f) or {}
 
         # Get timeout_ms value from hooks section
         hooks_config = config.get("hooks", {})
         timeout_ms = hooks_config.get("timeout_ms", 5000)
 
         return int(timeout_ms)
-    except (json.JSONDecodeError, FileNotFoundError, KeyError, ValueError):
+    except (yaml.YAMLError, FileNotFoundError, KeyError, ValueError):
         logger.warning("Failed to load hook timeout from config, using default 5000ms")
         return 5000
 
 
 def get_graceful_degradation() -> bool:
     """
-    Load graceful_degradation setting from .moai/config/config.json
+    Load graceful_degradation setting from .moai/config/config.yaml
 
     Returns:
         bool: graceful_degradation setting value, returns default True if not configured
     """
     try:
-        config_path = Path(".moai/config/config.json")
+        config_path = Path(".moai/config/config.yaml")
         if not config_path.exists():
             return True  # Default value
 
         with open(config_path, "r", encoding="utf-8") as f:
-            config = json.load(f)
+            config = yaml.safe_load(f) or {}
 
         # Get graceful_degradation value from hooks section
         hooks_config = config.get("hooks", {})
         return hooks_config.get("graceful_degradation", True)
-    except (json.JSONDecodeError, FileNotFoundError, KeyError):
-        logger.warning(
-            "Failed to load graceful_degradation from config, using default True"
-        )
+    except (yaml.YAMLError, FileNotFoundError, KeyError):
+        logger.warning("Failed to load graceful_degradation from config, using default True")
         return True
